@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '4.15';
+our $VERSION = '4.23';
 
 URPM->bootstrap($VERSION);
 
@@ -32,7 +32,7 @@ sub set_nofatal {
 
 sub packages_providing {
     my ($urpm, $name) = @_;
-    grep { $_ } map { $urpm->{depslist}[$_] } keys %{$urpm->{provides}{$name} || {}};
+    grep { $_ } map { $urpm->{depslist}[$_] } sort { $a <=> $b } keys %{$urpm->{provides}{$name} || {}};
 }
 
 sub packages_obsoleting {
@@ -292,7 +292,7 @@ URPM - Manipulate RPM files and headers
 =head1 DESCRIPTION
 
 The URPM module allows you to manipulate RPM files, RPM header files and
-hdlist files and manage them in memory. It is notably used by the C<urpmi>
+hdlist files and manage them in memory. It is notably used by the L<urpmi>
 utility. It provides four classes : C<URPM>, C<URPM::DB>, C<URPM::Package>,
 and C<URPM::Transaction>.
 
@@ -457,6 +457,8 @@ Rebuilds the RPM database (like C<rpm --rebuilddb>). $prefix defaults to C<"">.
 Executes the specified callback (a code reference) for each package
 in the DB, passing a C<URPM::Package> object as argument the callback.
 
+Returns the number of packages seen (all).
+
 =item $db->traverse_tag($tag,$names,$callback)
 
 $tag may be one of C<name>, C<whatprovides>, C<whatrequires>, C<whatconflicts>,
@@ -465,12 +467,16 @@ $names is a reference to an array, holding the acceptable values of the said
 tag for the searched variables.
 Then, $callback is called for each matching package in the DB.
 
+Returns the number of packages seen (all those that matched provided names).
+
 =item $db->traverse_tag_find($tag,$name,$callback)
 
 Quite similar to C<traverse_tag>, but stops when $callback returns true.
 
 (also note that only one $name is handled)
 
+Returns whether callback returned true once.
+
 =item $db->create_transaction()
 
 Creates and returns a new transaction (an C<URPM::Transaction> object) on the
@@ -766,7 +772,6 @@ Recognized options are:
     nosize => 0 / 1
     noscripts => 0 / 1
     oldpackage => 0 / 1
-    repackage => 0 / 1
     test => 0 / 1
     translate_message => 1
 
@@ -811,6 +816,12 @@ Delete a macro.
 
 Destroys macros.
 
+=back
+
+=head2 Misc other functions
+
+=over
+
 =item setVerbosity($level)
 
 Sets rpm verbosity level. $level is an integer between 2 (RPMMESS_CRIT) and 7
@@ -889,7 +900,7 @@ Copyright 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright 2005, 2006, 2007, 2008 Mandriva SA
 
-Copyright 2011, 2012, Mangeia
+Copyright 2011, 2012, Mageia
 
 FranE<ccedil>ois Pons (original author), Rafael Garcia-Suarez, Pixel, Thierry Vignaud <tv@mageia.org> (current maintainer)
 
